# Effective Quadratures
**Version 8.0**

Tools for machine learning with polynomials.

# Installation and Documentation
Please visit www.effective-quadratures.org

# Community guidelines
If you have contributions, questions, or feedback use either the Github repository, or contact: contact <at> effective-quadratures.org
